@@ -26,10 +26,10 @@ are_ids <- function(
   x
 ) {
   if (is.null(x)) return(FALSE)
-  if (beautier::is_id(x)) return(TRUE)
+  if (is_id(x)) return(TRUE)
   if (!is.vector(x)) return(FALSE)
   for (i in x) {
-    if (!beautier::is_id(i)) return(FALSE)
+    if (!is_id(i)) return(FALSE)
   }
   return(TRUE)
 }
