@@ -7,9 +7,9 @@
 are_init_site_models <- function(
   x
 ) {
-  if (!beautier::are_site_models(x)) return(FALSE)
+  if (!are_site_models(x)) return(FALSE)
   for (i in x) {
-    if (!beautier::is_init_site_model(i)) return(FALSE)
+    if (!is_init_site_model(i)) return(FALSE)
   }
   return(TRUE)
 }
