@@ -9,13 +9,13 @@ beta_parameter_to_xml <- function(
   beta_parameter,
   beauti_options = create_beauti_options()
 ) {
-  beautier::check_beauti_options(beauti_options)
+  check_beauti_options(beauti_options)
   # Don't be smart yet
   parameter <- beta_parameter
-  testit::assert(beautier::is_beta_param(parameter))
+  check_true(is_beta_param(parameter))
   id <- parameter$id
-  testit::assert(beautier::is_id(id))
-  testit::assert(parameter$estimate == FALSE)
+  check_true(is_id(id))
+  check_true(parameter$estimate == FALSE)
   estimate <- ifelse(parameter$estimate == TRUE, "true", "false")
   xml <- paste0(
     "<parameter ",
