@@ -2,6 +2,7 @@
 #'
 #' Will \link{stop} if not
 #' @inheritParams default_params_doc
+#' @return nothing, will \link{stop} if needed
 #' @export
 check_file_and_model_agree <- function(
   input_filename,
@@ -11,8 +12,8 @@ check_file_and_model_agree <- function(
 
   # If there is a CBS tree prior, the number of groups it has
   # must be equals or more than the number of taxa in the alignment
-  if (beautier::is_cbs_tree_prior(inference_model$tree_prior)) {
-    n_taxa <- beautier::get_n_taxa(input_filename)
+  if (is_cbs_tree_prior(inference_model$tree_prior)) {
+    n_taxa <- get_n_taxa(input_filename)
     group_sizes_dimension <- inference_model$tree_prior$group_sizes_dimension
     if (n_taxa <= group_sizes_dimension) {
       stop(
@@ -23,11 +24,11 @@ check_file_and_model_agree <- function(
   }
 
   # All MRCA prior's alignment IDs must match the FASTA file IDs
-  if (!beautier::is_one_na(inference_model$mrca_prior)) {
-    testit::assert(beautier::is_mrca_prior(inference_model$mrca_prior))
+  if (!is_one_na(inference_model$mrca_prior)) {
+    check_true(is_mrca_prior(inference_model$mrca_prior))
 
     if (
-      !beautier::is_mrca_align_id_in_fasta(
+      !is_mrca_align_id_in_fasta(
         mrca_prior = inference_model$mrca_prior,
         fasta_filename = input_filename
       )
@@ -38,7 +39,7 @@ check_file_and_model_agree <- function(
           "Use 'get_alignment_id' on the FASTA filename ",
           "to get the correct alignment ID. ",
           "Alignment IDs: ",
-          beautier::get_alignment_id(input_filename),
+          get_alignment_id(input_filename),
           ". MRCA alignment ID: ", inference_model$mrca_prior$alignment_id
         )
       )
@@ -46,9 +47,9 @@ check_file_and_model_agree <- function(
   }
 
   # All MRCA prior's taxa names must be FASTA file taxa names
-  if (!beautier::is_one_na(inference_model$mrca_prior)) {
+  if (!is_one_na(inference_model$mrca_prior)) {
     if (
-      !beautier::are_mrca_taxon_names_in_fasta(
+      !are_mrca_taxon_names_in_fasta(
         mrca_prior = inference_model$mrca_prior,
         fasta_filename = input_filename
       )
@@ -56,4 +57,5 @@ check_file_and_model_agree <- function(
       stop("All MRCA prior's taxa names must be FASTA file taxa names")
     }
   }
+  invisible(NULL)
 }
