@@ -2,9 +2,10 @@
 #'
 #' Will \link{stop} if not.
 #' @inheritParams default_params_doc
+#' @return No return value, called for side effects
 #' @export
 check_mrca_prior_taxa_names <- function(taxa_names) {
-  if (beautier::is_one_na(taxa_names)) return()
+  if (is_one_na(taxa_names)) return()
   if (length(taxa_names) == 0 ||
       !is.character(taxa_names) ||
       sum(taxa_names == "") > 0
@@ -15,4 +16,6 @@ check_mrca_prior_taxa_names <- function(taxa_names) {
   ) {
     stop("'taxa_names' must be NA or all names must be unique")
   }
+
+  invisible(taxa_names)
 }
