@@ -21,10 +21,10 @@
 #' @export
 check_tree_prior <- function(tree_prior) {
 
-  if (beautier::is_tree_prior(tree_prior)) {
+  if (is_tree_prior(tree_prior)) {
     return()
   }
-  if (length(tree_prior) == 1 && beautier::is_tree_prior(tree_prior[[1]])) {
+  if (length(tree_prior) == 1 && is_tree_prior(tree_prior[[1]])) {
     return()
   }
   stop(
