@@ -9,12 +9,12 @@
 clock_model_to_xml_operators <- function(
   inference_model
 ) {
-  if (beautier::is_strict_clock_model(inference_model$clock_model)) {
+  if (is_strict_clock_model(inference_model$clock_model)) {
     return(strict_clock_model_to_xml_operators(inference_model))
   } else {
     # Will fail on unimplemented clock models
-    testthat::expect_true(
-      beautier::is_rln_clock_model(inference_model$clock_model)
+    check_true(
+      is_rln_clock_model(inference_model$clock_model)
     )
     return(rln_clock_model_to_xml_operators(inference_model))
   }
