@@ -17,14 +17,14 @@
 create_beast2_input <- function(
   input_filename,
   tipdates_filename = NA,
-  site_model = beautier::create_jc69_site_model(),
-  clock_model = beautier::create_strict_clock_model(),
-  tree_prior = beautier::create_yule_tree_prior(),
+  site_model = create_jc69_site_model(),
+  clock_model = create_strict_clock_model(),
+  tree_prior = create_yule_tree_prior(),
   mrca_prior = NA,
-  mcmc = beautier::create_mcmc(),
-  beauti_options = beautier::create_beauti_options()
+  mcmc = create_mcmc(),
+  beauti_options = create_beauti_options()
 ) {
-  inference_model <- beautier::create_inference_model(
+  inference_model <- create_inference_model(
     site_model = site_model,
     clock_model = clock_model,
     tree_prior = tree_prior,
@@ -33,7 +33,7 @@ create_beast2_input <- function(
     beauti_options = beauti_options,
     tipdates_filename = tipdates_filename
   )
-  beautier::create_beast2_input_from_model(
+  create_beast2_input_from_model(
     input_filename = input_filename,
     inference_model = inference_model
   )
