@@ -14,27 +14,26 @@
 #' @export
 create_beast2_input_data <- function(
   input_filename,
-  beauti_options = beautier::create_beauti_options()
+  beauti_options = create_beauti_options()
 ) {
-  testthat::expect_equal(length(input_filename), 1)
-  testthat::expect_true(file.exists(input_filename))
+  check_file_exists(input_filename)
 
   # Data opening tag
-  id <- beautier::get_alignment_id(
+  id <- get_alignment_id(
     fasta_filename = input_filename,
     capitalize_first_char_id = beauti_options$capitalize_first_char_id
   )
-  data_start_text <- beautier::create_data_xml(
+  data_start_text <- create_data_xml(
     id = id,
     beast2_version = beauti_options$beast2_version
   )
   # Sequences
-  sequences_text <- beautier::create_beast2_input_data_sequences(
+  sequences_text <- create_beast2_input_data_sequences(
     input_fasta_filename = input_filename,
     beauti_options = beauti_options
   )
   # Data closing tag
-  data_close_text <- beautier::indent(
+  data_close_text <- indent(
     "</data>", n_spaces = beauti_options$sequence_indent - 4
   )
   if (beauti_options$beast2_version == "2.6") {
