@@ -38,35 +38,33 @@ create_beast2_input_from_model <- function(
   if (!file.exists(input_filename)) {
     stop("'input_filename' not found. Value: ", input_filename)
   }
-  beautier::check_inference_model(inference_model)
+  check_inference_model(inference_model)
 
-  inference_model <- beautier::init_inference_model(
+  inference_model <- init_inference_model(
     input_filename = input_filename,
     inference_model = inference_model
   )
 
   # Check if the combination of FASTA file and inference model agrees
-  beautier::check_file_and_model_agree(
+  check_file_and_model_agree(
     input_filename = input_filename,
     inference_model = inference_model
   )
 
   # Make a million show as 1000000 instead of 1e+06
-  old_scipen <- getOption("scipen")
+  # Use suprior syntax, thanks Victoria Wimmer
+  old <- options()
+  on.exit(options(old))
   options(scipen = 20)
 
-
-  text <- beautier::create_beast2_input_beast(
+  text <- create_beast2_input_beast(
     input_filename = input_filename,
     inference_model = inference_model
   )
   text[1] <- paste0(
-    beautier::create_xml_declaration(),
+    create_xml_declaration(),
     text[1]
   )
 
-  # Restore scipen
-  options(scipen = old_scipen)
-
   text
 }
