@@ -9,17 +9,17 @@ create_beast2_input_operators <- function(
   # Do not be smart yet
   site_models <- list(inference_model$site_model)
 
-  text <- beautier::tree_prior_to_xml_operators(
+  text <- tree_prior_to_xml_operators(
     inference_model = inference_model
   )
 
-  text <- c(text, beautier::site_models_to_xml_operators(site_models))
+  text <- c(text, site_models_to_xml_operators(site_models))
   text <- c(
     text,
-    beautier::clock_model_to_xml_operators(
+    clock_model_to_xml_operators(
       inference_model
     )
   )
-  text <- beautier::interspace(text)
+  text <- interspace(text)
   text
 }
