@@ -10,7 +10,7 @@
 #' @export
 create_beautier_tempfolder <- function() {
   dir.create(
-    dirname(beautier::get_beautier_tempfilename()),
+    dirname(get_beautier_tempfilename()),
     showWarnings = FALSE,
     recursive = TRUE
   )
