@@ -13,9 +13,9 @@
 #' @export
 create_clock_model_from_name <- function(clock_model_name) {
   if (clock_model_name == "strict") {
-    beautier::create_strict_clock_model()
+    create_strict_clock_model()
   } else {
-    testit::assert(clock_model_name == "relaxed_log_normal")
-    beautier::create_rln_clock_model()
+    check_true(clock_model_name == "relaxed_log_normal")
+    create_rln_clock_model()
   }
 }
