@@ -14,7 +14,7 @@ create_clock_models_from_names <- function(clock_model_names) {
   clock_models <- list()
   for (i in seq_along(clock_model_names)) {
     clock_model_name <- clock_model_names[i]
-    clock_models[[i]] <- beautier::create_clock_model_from_name(
+    clock_models[[i]] <- create_clock_model_from_name(
       clock_model_name
     )
   }
