@@ -48,15 +48,15 @@ create_gamma_site_model <- function(
   freq_equilibrium = "estimated",
   freq_prior_uniform_distr_id = 1000
 ) {
-  testthat::expect_true(beautier::is_id(freq_prior_uniform_distr_id))
+  check_true(is_id(freq_prior_uniform_distr_id))
   if (length(gamma_cat_count) == 1 &&
       gamma_cat_count >= 2 &&
-      beautier::is_one_na(gamma_shape_prior_distr)
+      is_one_na(gamma_shape_prior_distr)
   ) {
     # Cannot simplify, due to 1.0 becomes 1 in XML
-    gamma_shape_prior_distr <- beautier::create_exp_distr(
+    gamma_shape_prior_distr <- create_exp_distr(
       id = NA,
-      mean = beautier::create_mean_param(
+      mean = create_mean_param(
         id = NA,
         value = "1.0" # string to match XML
       )
@@ -70,6 +70,6 @@ create_gamma_site_model <- function(
     freq_equilibrium = freq_equilibrium,
     freq_prior_uniform_distr_id = freq_prior_uniform_distr_id
   )
-  beautier::check_gamma_site_model(gamma_site_model)
+  check_gamma_site_model(gamma_site_model)
   gamma_site_model
 }
