@@ -33,13 +33,13 @@
 #' check_empty_beautier_folder()
 #' @export
 create_rate_categories_state_node_xml <- function(inference_model) { # nolint indeed a long function name
-  beautier::check_inference_model(inference_model)
+  check_inference_model(inference_model)
   clock_model <- inference_model$clock_model
-  testthat::expect_true(beautier::is_rln_clock_model(clock_model))
+  check_true(is_rln_clock_model(clock_model))
   id <- clock_model$id
   dimension <- clock_model$dimension
-  testthat::expect_false(beautier::is_one_na(dimension))
-  testthat::expect_false(beautier::is_one_na(id))
+  check_false(is_one_na(dimension))
+  check_false(is_one_na(id))
   # dimension d = 2n - 2, where n is the number of taxa
   paste0(
     "<stateNode id=\"rateCategories.c:", id, "\" ",
