@@ -30,15 +30,15 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 create_test_inference_model <- function(
-  site_model = beautier::create_jc69_site_model(),
-  clock_model = beautier::create_strict_clock_model(),
-  tree_prior = beautier::create_yule_tree_prior(),
+  site_model = create_jc69_site_model(),
+  clock_model = create_strict_clock_model(),
+  tree_prior = create_yule_tree_prior(),
   mrca_prior = NA,
-  mcmc = beautier::create_test_mcmc(),
-  beauti_options = beautier::create_beauti_options(),
+  mcmc = create_test_mcmc(),
+  beauti_options = create_beauti_options(),
   tipdates_filename = NA
 ) {
-  beautier::create_inference_model(
+  create_inference_model(
     site_model = site_model,
     clock_model = clock_model,
     tree_prior = tree_prior,
