@@ -22,10 +22,10 @@
 #' @export
 create_tree_priors <- function() {
   list(
-    beautier::create_bd_tree_prior(),
-    beautier::create_cbs_tree_prior(),
-    beautier::create_ccp_tree_prior(),
-    beautier::create_cep_tree_prior(),
-    beautier::create_yule_tree_prior()
+    create_bd_tree_prior(),
+    create_cbs_tree_prior(),
+    create_ccp_tree_prior(),
+    create_cep_tree_prior(),
+    create_yule_tree_prior()
   )
 }
