@@ -29,13 +29,13 @@ create_ucld_mean_state_node_param_xml <- function(inference_model) { # nolint in
   if (inference_model$beauti_options$beast2_version == "2.4") {
     stop("The ucldMean stateNode was absent in BEAST v2.4")
   }
-  beautier::check_inference_model(inference_model)
+  check_inference_model(inference_model)
   clock_model <- inference_model$clock_model
   id <- clock_model$id
   mean_clock_rate <- clock_model$mean_clock_rate
-  testthat::expect_true(beautier::is_rln_clock_model(clock_model))
-  testthat::expect_false(beautier::is_one_na(id))
-  testthat::expect_false(beautier::is_one_na(mean_clock_rate))
+  check_true(is_rln_clock_model(clock_model))
+  check_false(is_one_na(id))
+  check_false(is_one_na(mean_clock_rate))
   xml <- paste0(
     "<parameter id=\"ucldMean.c:", id, "\" "
   )
