@@ -9,10 +9,10 @@ find_clock_model <- function(
   clock_models,
   id
 ) {
-  if (!beautier::are_clock_models(clock_models)) {
+  if (!are_clock_models(clock_models)) {
     stop("'clock_models' must be a list of clock models")
   }
-  if (!beautier::is_id(id)) {
+  if (!is_id(id)) {
     stop("'id' must be an ID")
   }
   for (clock_model in clock_models) {
