@@ -10,7 +10,7 @@ find_first_regex_line <- function(lines, regex) {
       string = lines[i],
       pattern = regex
     )
-    if (!beautier::is_one_na(match)) return(i)
+    if (!is_one_na(match)) return(i)
   }
   NA
 }
