@@ -4,6 +4,7 @@
 #' setting \code{inference_model$tipdates_filename} to \link{NA},
 #' there will be one filename less returned
 #' @inheritParams default_params_doc
+#' @return the filenames stored in an inference model
 #' @examples
 #' check_empty_beautier_folder()
 #'
@@ -13,10 +14,10 @@
 #' check_empty_beautier_folder()
 #' @export
 get_inference_model_filenames <- function(inference_model) {
-  beautier::check_inference_model(inference_model)
+  check_inference_model(inference_model)
   stats::na.omit(
     c(
-      beautier::get_mcmc_filenames(inference_model$mcmc),
+      get_mcmc_filenames(inference_model$mcmc),
       inference_model$tipdates_filename
     )
   )
