@@ -17,5 +17,5 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 get_fasta_filename <- function() {
-  beautier::get_beautier_path("test_output_0.fas")
+  get_beautier_path("test_output_0.fas")
 }
