@@ -25,19 +25,19 @@
 get_tree_prior_n_distrs <- function(
   tree_prior
 ) {
-  if (!beautier::is_tree_prior(tree_prior)) {
+  if (!is_tree_prior(tree_prior)) {
     stop("'tree_prior' must be a tree prior")
   }
-  if (beautier::is_bd_tree_prior(tree_prior)) {
+  if (is_bd_tree_prior(tree_prior)) {
     return(2)
-  } else if (beautier::is_cbs_tree_prior(tree_prior)) {
+  } else if (is_cbs_tree_prior(tree_prior)) {
     return(0)
-  } else if (beautier::is_ccp_tree_prior(tree_prior)) {
+  } else if (is_ccp_tree_prior(tree_prior)) {
     return(1)
-  } else if (beautier::is_cep_tree_prior(tree_prior)) {
+  } else if (is_cep_tree_prior(tree_prior)) {
     return(2)
   } else {
-    testit::assert(beautier::is_yule_tree_prior(tree_prior))
+    check_true(is_yule_tree_prior(tree_prior))
     return(1)
   }
 }
