@@ -18,13 +18,13 @@
 get_tree_priors_n_distrs <- function(
   tree_priors
 ) {
-  if (!beautier::are_tree_priors(tree_priors)) {
+  if (!are_tree_priors(tree_priors)) {
     stop("'tree_priors' must be a list of one or more tree priors")
   }
   n <- 0
   for (tree_prior in tree_priors) {
-    testit::assert(beautier::is_tree_prior(tree_prior))
-    n <- n + beautier::get_tree_prior_n_distrs(tree_prior)
+    check_true(is_tree_prior(tree_prior))
+    n <- n + get_tree_prior_n_distrs(tree_prior)
   }
   n
 }
