@@ -10,10 +10,9 @@ indent <- function(
   text,
   n_spaces = 4
 ) {
-  if (n_spaces < 0) {
-    stop("'n_spaces' must be a positive integer")
-  }
-  testthat::expect_false(is.null(text))
+  check_number_whole(n_spaces, min = 0)
+
+  check_false(is.null(text))
   for (i in seq_along(text)) {
     if (text[i] == "") next
     spaces <- paste(rep(" ", n_spaces), collapse = "")
