@@ -11,46 +11,46 @@ init_tree_priors <- function(
   distr_id = 0,
   param_id = 0
 ) {
-  testit::assert(beautier::are_tree_priors(tree_priors))
+  check_true(are_tree_priors(tree_priors))
 
   for (i in seq_along(tree_priors)) {
     tree_prior <- tree_priors[[i]]
-    testit::assert(beautier::is_tree_prior(tree_prior))
+    check_true(is_tree_prior(tree_prior))
 
-    if (beautier::is_bd_tree_prior(tree_prior)) {
-      if (!beautier::is_init_bd_tree_prior(tree_prior)) {
-        tree_prior <- beautier::init_bd_tree_prior(
+    if (is_bd_tree_prior(tree_prior)) {
+      if (!is_init_bd_tree_prior(tree_prior)) {
+        tree_prior <- init_bd_tree_prior(
           tree_prior, distr_id = distr_id, param_id = param_id
         )
       }
-    } else if (beautier::is_cbs_tree_prior(tree_prior)) {
+    } else if (is_cbs_tree_prior(tree_prior)) {
       # Nothing to do
-    } else if (beautier::is_ccp_tree_prior(tree_prior)) {
-      if (!beautier::is_init_ccp_tree_prior(tree_prior)) {
-        tree_prior <- beautier::init_ccp_tree_prior(
+    } else if (is_ccp_tree_prior(tree_prior)) {
+      if (!is_init_ccp_tree_prior(tree_prior)) {
+        tree_prior <- init_ccp_tree_prior(
           tree_prior, distr_id = distr_id, param_id = param_id
         )
       }
-    } else if (beautier::is_cep_tree_prior(tree_prior)) {
-      if (!beautier::is_init_cep_tree_prior(tree_prior)) {
-        tree_prior <- beautier::init_cep_tree_prior(
+    } else if (is_cep_tree_prior(tree_prior)) {
+      if (!is_init_cep_tree_prior(tree_prior)) {
+        tree_prior <- init_cep_tree_prior(
           tree_prior, distr_id = distr_id, param_id = param_id
         )
       }
     } else {
-      testit::assert(beautier::is_yule_tree_prior(tree_prior))
-      if (!beautier::is_init_yule_tree_prior(tree_prior)) {
-        tree_prior <- beautier::init_yule_tree_prior(
+      check_true(is_yule_tree_prior(tree_prior))
+      if (!is_init_yule_tree_prior(tree_prior)) {
+        tree_prior <- init_yule_tree_prior(
           tree_prior,
           distr_id = distr_id,
           param_id = param_id
         )
       }
     }
-    distr_id <- distr_id + beautier::get_tree_prior_n_distrs(tree_prior)
-    param_id <- param_id + beautier::get_tree_prior_n_params(tree_prior)
+    distr_id <- distr_id + get_tree_prior_n_distrs(tree_prior)
+    param_id <- param_id + get_tree_prior_n_params(tree_prior)
 
-    if (beautier::is_one_na(tree_prior$id)) tree_prior$id <- ids[i]
+    if (is_one_na(tree_prior$id)) tree_prior$id <- ids[i]
     tree_priors[[i]] <- tree_prior
   }
   tree_priors
@@ -66,18 +66,18 @@ init_bd_tree_prior <- function(
   distr_id,
   param_id
 ) {
-  testit::assert(beautier::is_bd_tree_prior(bd_tree_prior))
+  check_true(is_bd_tree_prior(bd_tree_prior))
 
-  result <- beautier::create_bd_tree_prior(
-    birth_rate_distr = beautier::init_distr(
+  result <- create_bd_tree_prior(
+    birth_rate_distr = init_distr(
       bd_tree_prior$birth_rate_distr,
       distr_id,
       param_id
     ),
-    death_rate_distr = beautier::init_distr(
+    death_rate_distr = init_distr(
       bd_tree_prior$death_rate_distr,
       distr_id + 1,
-      param_id + beautier::get_distr_n_params(bd_tree_prior$birth_rate_distr)
+      param_id + get_distr_n_params(bd_tree_prior$birth_rate_distr)
     )
   )
 
@@ -95,10 +95,10 @@ init_ccp_tree_prior <- function(
   distr_id,
   param_id
 ) {
-  testit::assert(beautier::is_ccp_tree_prior(ccp_tree_prior))
+  check_true(is_ccp_tree_prior(ccp_tree_prior))
 
-  result <- beautier::create_ccp_tree_prior(
-    pop_size_distr = beautier::init_distr(
+  result <- create_ccp_tree_prior(
+    pop_size_distr = init_distr(
       ccp_tree_prior$pop_size_distr,
       distr_id,
       param_id
@@ -117,25 +117,25 @@ init_cep_tree_prior <- function(
   distr_id,
   param_id
 ) {
-  testit::assert(beautier::is_cep_tree_prior(cep_tree_prior))
-  testit::assert(!beautier::is_one_na(distr_id))
-  testit::assert(!beautier::is_one_na(param_id))
-  testit::assert(
-    !beautier::is_one_na(
-      beautier::get_distr_n_params(cep_tree_prior$pop_size_distr)
+  check_true(is_cep_tree_prior(cep_tree_prior))
+  check_true(!is_one_na(distr_id))
+  check_true(!is_one_na(param_id))
+  check_true(
+    !is_one_na(
+      get_distr_n_params(cep_tree_prior$pop_size_distr)
     )
   )
 
-  result <- beautier::create_cep_tree_prior(
-    pop_size_distr = beautier::init_distr(
+  result <- create_cep_tree_prior(
+    pop_size_distr = init_distr(
       cep_tree_prior$pop_size_distr,
       distr_id,
       param_id
     ),
-    growth_rate_distr = beautier::init_distr(
+    growth_rate_distr = init_distr(
       cep_tree_prior$growth_rate_distr,
       distr_id + 1,
-      param_id + beautier::get_distr_n_params(cep_tree_prior$pop_size_distr)
+      param_id + get_distr_n_params(cep_tree_prior$pop_size_distr)
     )
   )
 
@@ -152,10 +152,10 @@ init_yule_tree_prior <- function(
   distr_id,
   param_id
 ) {
-  testit::assert(beautier::is_yule_tree_prior(yule_tree_prior))
+  check_true(is_yule_tree_prior(yule_tree_prior))
 
-  result <- beautier::create_yule_tree_prior(
-    birth_rate_distr = beautier::init_distr(
+  result <- create_yule_tree_prior(
+    birth_rate_distr = init_distr(
       yule_tree_prior$birth_rate_distr,
       distr_id,
       param_id
