@@ -8,7 +8,7 @@ is_in_patterns <- function(line, patterns) {
 
   for (pattern in patterns) {
     if (
-      !beautier::is_one_na(
+      !is_one_na(
         stringr::str_match(string = line, pattern = pattern)[1, 1]
       )
     ) {
