@@ -5,7 +5,7 @@
 is_inference_model <- function(x) {
   result <- FALSE
   tryCatch({
-    beautier::check_inference_model(x)
+    check_inference_model(x)
     result <- TRUE
   },
     error = function(e) {} # nolint do not care about e
