@@ -8,8 +8,8 @@
 is_init_gamma_site_model <- function(
   x
 ) {
-  if (!beautier::is_gamma_site_model(x)) return(FALSE)
-  if (beautier::is_one_na(x$gamma_shape_prior_distr)) return(TRUE)
-  if (!beautier::is_init_distr(x$gamma_shape_prior_distr)) return(FALSE)
+  if (!is_gamma_site_model(x)) return(FALSE)
+  if (is_one_na(x$gamma_shape_prior_distr)) return(TRUE)
+  if (!is_init_distr(x$gamma_shape_prior_distr)) return(FALSE)
   TRUE
 }
