@@ -9,11 +9,11 @@ is_mrca_align_ids_in_fastas <- function(
   mrca_prior,
   fasta_filenames
 ) {
-  testit::assert(beautier::is_mrca_prior(mrca_prior))
-  ids <- beautier::get_alignment_ids_from_fasta_filenames(fasta_filenames)
-  testit::assert(beautier::is_mrca_prior(mrca_prior))
-  testit::assert(!beautier::is_one_na(mrca_prior))
-  testit::assert("alignment_id" %in% names(mrca_prior))
-  testit::assert(!beautier::is_one_na(mrca_prior$alignment_id))
+  check_true(is_mrca_prior(mrca_prior))
+  ids <- get_alignment_ids_from_fasta_filenames(fasta_filenames)
+  check_true(is_mrca_prior(mrca_prior))
+  check_true(!is_one_na(mrca_prior))
+  check_true("alignment_id" %in% names(mrca_prior))
+  check_true(!is_one_na(mrca_prior$alignment_id))
   mrca_prior$alignment_id %in% ids
 }
