@@ -43,7 +43,7 @@ is_param <- function(
 ) {
   result <- FALSE
   tryCatch({
-    beautier::check_param(x)
+    check_param(x)
     result <- TRUE
   },
     error = function(e) {} # nolint do not care about e
@@ -93,7 +93,7 @@ is_param <- function(
 is_alpha_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "alpha"
 }
 
@@ -140,7 +140,7 @@ is_alpha_param <- function(
 is_b_pop_sizes_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "b_pop_sizes"
 }
 
@@ -187,7 +187,7 @@ is_b_pop_sizes_param <- function(
 is_beta_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "beta"
 }
 
@@ -233,7 +233,7 @@ is_beta_param <- function(
 is_clock_rate_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "clock_rate"
 }
 
@@ -284,7 +284,7 @@ is_clock_rate_param <- function(
 is_freq_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   if (x$name != "freqParameter") return(FALSE) # redundant name
   if (!"lower" %in% names(x)) return(FALSE)
   if (!"upper" %in% names(x)) return(FALSE)
@@ -338,7 +338,7 @@ is_freq_param <- function(
 is_kappa_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   if (x$name != "kappa") return(FALSE)
 
   if (!"lower" %in% names(x)) return(FALSE)
@@ -390,7 +390,7 @@ is_kappa_param <- function(
 is_kappa_1_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   if (x$name != "kappa_1") return(FALSE)
 
   if (!"lower" %in% names(x)) return(FALSE)
@@ -441,7 +441,7 @@ is_kappa_1_param <- function(
 is_kappa_2_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   if (x$name != "kappa_2") return(FALSE)
 
   if (!"lower" %in% names(x)) return(FALSE)
@@ -491,7 +491,7 @@ is_kappa_2_param <- function(
 is_lambda_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "lambda"
 }
 
@@ -536,7 +536,7 @@ is_lambda_param <- function(
 is_mean_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "mean"
 }
 
@@ -583,7 +583,7 @@ is_mean_param <- function(
 is_mu_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "mu"
 }
 
@@ -630,7 +630,7 @@ is_mu_param <- function(
 is_rate_ac_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "rate_ac"
 }
 
@@ -677,7 +677,7 @@ is_rate_ac_param <- function(
 is_rate_ag_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "rate_ag"
 }
 
@@ -724,7 +724,7 @@ is_rate_ag_param <- function(
 is_rate_at_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "rate_at"
 }
 
@@ -771,7 +771,7 @@ is_rate_at_param <- function(
 is_rate_cg_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "rate_cg"
 }
 
@@ -818,7 +818,7 @@ is_rate_cg_param <- function(
 is_rate_ct_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "rate_ct"
 }
 
@@ -865,7 +865,7 @@ is_rate_ct_param <- function(
 is_rate_gt_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "rate_gt"
 }
 
@@ -911,7 +911,7 @@ is_rate_gt_param <- function(
 is_s_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "s"
 }
 
@@ -957,7 +957,7 @@ is_s_param <- function(
 is_scale_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "scale"
 }
 
@@ -1003,6 +1003,6 @@ is_scale_param <- function(
 is_sigma_param <- function(
   x
 ) {
-  if (!beautier::is_param(x)) return(FALSE)
+  if (!is_param(x)) return(FALSE)
   x$name == "sigma"
 }
