@@ -8,15 +8,15 @@ jc69_site_model_to_xml_state <- function(
   site_model,
   beauti_options = create_beauti_options()
 ) {
-  testit::assert(beautier::is_site_model(site_model))
-  beautier::check_beauti_options(beauti_options)
+  check_true(is_site_model(site_model))
+  check_beauti_options(beauti_options)
   id <- site_model$id
-  testit::assert(beautier::is_id(id))
-  testthat::expect_true(beautier::is_jc69_site_model(site_model))
+  check_true(is_id(id))
+  check_true(is_jc69_site_model(site_model))
   text <- NULL
   text <- c(
     text,
-    beautier::gamma_site_model_to_xml_state(site_model$gamma_site_model, id)
+    gamma_site_model_to_xml_state(site_model$gamma_site_model, id)
   )
   text
 }
