@@ -9,9 +9,9 @@ m_param_to_xml <- function(
   m_param,
   beauti_options = create_beauti_options()
 ) {
-  testthat::expect_true(beautier::is_m_param(m_param))
-  beautier::check_beauti_options(beauti_options)
-  testthat::expect_true(beautier::is_id(m_param$id))
+  check_true(is_m_param(m_param))
+  check_beauti_options(beauti_options)
+  check_true(is_id(m_param$id))
   xml <- paste0(
     "<parameter ",
     "id=\"RealParameter.", m_param$id, "\" "
