@@ -24,16 +24,16 @@ mrca_prior_to_xml_prior_distr <- function(
   # Don't be smart yet
   mrca_prior <- inference_model$mrca_prior
   taxa_names_with_ids <- NULL
-  has_non_strict_clock_model <- beautier::get_has_non_strict_clock_model(
+  has_non_strict_clock_model <- get_has_non_strict_clock_model(
     list(inference_model$clock_model)
   )
-  testit::assert(beautier::is_mrca_prior(mrca_prior))
+  check_true(is_mrca_prior(mrca_prior))
   text <- NULL
   if (!has_non_strict_clock_model &&
-      !beautier::is_one_na(mrca_prior$mrca_distr) &&
-      beautier::is_one_na(inference_model$tipdates_filename)
+      !is_one_na(mrca_prior$mrca_distr) &&
+      is_one_na(inference_model$tipdates_filename)
   ) {
-    testit::assert(!beautier::is_one_na(mrca_prior$alignment_id))
+    check_true(!is_one_na(mrca_prior$alignment_id))
     text <- c(
       text,
       paste0(
@@ -44,9 +44,9 @@ mrca_prior_to_xml_prior_distr <- function(
     )
     text <- c(
       text,
-      beautier::indent(
-        beautier::distr_to_xml(
-          beautier::create_uniform_distr(
+      indent(
+        distr_to_xml(
+          create_uniform_distr(
             id = mrca_prior$clock_prior_distr_id
           ),
           beauti_options = inference_model$beauti_options
@@ -63,7 +63,7 @@ mrca_prior_to_xml_prior_distr <- function(
   if (mrca_prior$is_monophyletic) {
     opening_tag <- paste0(opening_tag, "monophyletic=\"true\" ")
   }
-  testit::assert(!beautier::is_one_na(mrca_prior$alignment_id))
+  check_true(!is_one_na(mrca_prior$alignment_id))
   opening_tag <- paste0(
     opening_tag, "tree=\"@Tree.t:", mrca_prior$alignment_id, "\">"
   )
@@ -71,18 +71,18 @@ mrca_prior_to_xml_prior_distr <- function(
   text <- c(text, opening_tag)
   text <- c(
     text,
-    beautier::indent(
-      beautier::mrca_prior_to_xml_taxonset(
+    indent(
+      mrca_prior_to_xml_taxonset(
         mrca_prior,
         taxa_names_with_ids
       )
     )
   )
-  if (beautier::is_distr(mrca_prior$mrca_distr)) {
+  if (is_distr(mrca_prior$mrca_distr)) {
     text <- c(
       text,
-      beautier::indent(
-        beautier::distr_to_xml(
+      indent(
+        distr_to_xml(
           mrca_prior$mrca_distr,
           beauti_options = inference_model$beauti_options
         )
