@@ -8,33 +8,33 @@ site_model_to_xml_state <- function(
   site_model,
   beauti_options = create_beauti_options()
 ) {
-  beautier::check_site_model(site_model)
-  beautier::check_beauti_options(beauti_options)
-  if (beautier::is_gtr_site_model(site_model)) {
+  check_site_model(site_model)
+  check_beauti_options(beauti_options)
+  if (is_gtr_site_model(site_model)) {
     return(
-      beautier::gtr_site_model_to_xml_state(
+      gtr_site_model_to_xml_state(
         site_model = site_model,
         beauti_options = beauti_options
       )
     )
-  } else if (beautier::is_hky_site_model(site_model)) {
+  } else if (is_hky_site_model(site_model)) {
     return(
-      beautier::hky_site_model_to_xml_state(
+      hky_site_model_to_xml_state(
         site_model = site_model,
         beauti_options = beauti_options
       )
     )
-  } else if (beautier::is_tn93_site_model(site_model)) {
+  } else if (is_tn93_site_model(site_model)) {
     return(
-      beautier::tn93_site_model_to_xml_state(
+      tn93_site_model_to_xml_state(
         site_model = site_model,
         beauti_options = beauti_options
       )
     )
   } else {
-    testthat::expect_true(beautier::is_jc69_site_model(site_model))
+    check_true(is_jc69_site_model(site_model))
     return(
-      beautier::jc69_site_model_to_xml_state(
+      jc69_site_model_to_xml_state(
         site_model = site_model,
         beauti_options = beauti_options
       )
