@@ -18,7 +18,7 @@ site_models_to_xml_tracelog <- function(
 ) {
   text <- NULL
   for (site_model in site_models) {
-    text <- c(text, beautier::site_model_to_xml_tracelog(site_model))
+    text <- c(text, site_model_to_xml_tracelog(site_model))
   }
   text
 }
